<template>
    <div class="app-container">
        <div class="filter-container">
            <div style="display: block;">
                <div class="basic_search" style="padding-top: 10px;">
                    <span>按时间查询：</span>
                    <el-date-picker
                        value-format="yyyy-MM-dd HH:mm:ss"
                        v-model="validTime"
                        type="daterange"
                        :default-time="['00:00:00','23:59:59']"
                        :picker-options="pickerOptions"
                        range-separator="-"
                        start-placeholder="开始日期"
                        end-placeholder="结束日期"
                    >
                    </el-date-picker>
                </div>
                <div class="basic_search" style="padding-top: 10px;margin-left: 15px">
                    <span>企业类型：</span>
                    <el-select v-model="listQuery.filter.safetysupervision" clearable filterable>
                        <el-option value="" label="全部">
                        </el-option>
                        <el-option
                            v-for="item in safetysupervision"
                            :key="item"
                            :label="item"
                            :value="item"
                        >
                        </el-option>
                    </el-select>
                </div>
                <div class="basic_search" style="margin-right: 10px">
                    <el-button style="margin-left: 10px;" type="primary" icon="el-icon-search" @click="searchCityInOutSearch('查询','')">查询</el-button>
                    <el-button style="margin-left: 10px;" type="primary" icon="el-icon-download" @click="exportToExcel">导出</el-button>
                </div>
            </div>
        </div>
        <div class="table_content">
            <el-table
                v-loading="listLoading"
                :key="tableKey"
                :data="personPurchaseData"
                border
                fit
                highlight-current-row
                style="width: 100%;">
                <el-table-column label="序号" type="index" align="center" width="60"/>
                <el-table-column label="地区" prop="name" align="center">
                    <template slot-scope="scope">
                        <span class="click-color" @click="openDetailDialog(scope.row.name,validTime,listQuery.filter.safetysupervision)">{{scope.row.name}}</span>
                    </template>
                </el-table-column>
                <el-table-column label="入库数量(箱)" prop="innum" align="center">
                </el-table-column>
                <el-table-column label="出货数量(箱)" prop="outnum" align="center">
                </el-table-column>
                <el-table-column label="销售数量(箱)" prop="salenum" align="center">
                </el-table-column>
                <el-table-column label="售销额(万元)" prop="sales" align="center">
                </el-table-column>

            </el-table>
            <br>
            <el-pagination
                v-show="recordTotal>0"
                :current-page="currentPage"
                :page-sizes="[20, 50, 100, 200]"
                :page-size="pageSize"
                :total="recordTotal"
                layout="total, sizes, prev, pager, next, jumper"
                background
                style="float:right;"
                @size-change="handleSizeChange"
                @current-change="handleCurrentChange"></el-pagination>
            <br>
        </div>
        <detail ref="detail"></detail>
    </div>
</template>

<script>
    import detail from './cityInAndOut/index'
import { computePageCount } from "../../utils";
import {exportArea, getPersonListData,getCityInOut} from "../../api/productPurchaseSearch";

export default {
    name: "addSelfExam",
    data(){
        return{
            tableKey:'',
          validTime:['',''],
            listQuery: {
                pageSize:20,
                pageIndex:1,
                filter: {
                    starttime: '',
                    endtime: '',
                    safetysupervision:''
                },
            },
              safetysupervision:[
                "烟花爆竹生产",
                "烟花爆竹批发经营",
                "烟花爆竹零售经营（短期）",
                "烟花爆竹零售经营（长期）",
              ],
            pageSize: 20,
            recordTotal: 0,
            currentPage: 1,
            pageTotal: 0,
            listLoading:false,
            personPurchaseData:[],
            pickerOptions: {
            shortcuts: [{
              text: '最近一周',
              onClick(picker) {
                const end = new Date();
                const start = new Date();
                start.setTime(start.getTime() - 3600 * 1000 * 24 * 7);
                picker.$emit('pick', [start, end]);
              }
            }, {
              text: '最近一个月',
              onClick(picker) {
                const end = new Date();
                const start = new Date();
                start.setTime(start.getTime() - 3600 * 1000 * 24 * 30);
                picker.$emit('pick', [start, end]);
              }
            }]
          },
        }
    },
    components:{
      detail
    },
    created() {
      this.initValidTime()
        this.getCityInOutList()
    },
    watch: {
    },
    methods:{
        async getCityInOutList(){
            this.listLoading = true
          if( this.validTime !== null ){
            this.listQuery.filter.starttime = this.validTime[0]
            this.listQuery.filter.endtime = this.validTime[1]
          }else{
            this.listQuery.filter.starttime = ''
            this.listQuery.filter.endtime = ''
          }
            let res = await getCityInOut(this.listQuery)
            if(res.data.code === "200"){
                this.recordTotal = res.data.result.total
                this.pageSize = res.data.result.size
                this.pageTotal = computePageCount(res.data.result.total, res.data.result.size)
                this.currentPage = res.data.result.current
                this.personPurchaseData = res.data.result.records
            }else{
                this.$message({
                    type:'warning',
                    message:res.data.message
                })
            }
            this.listLoading = false
        },



        async exportToExcel(){
            if( this.validTime !== null ){
                this.listQuery.filter.starttime = this.validTime[0]
                this.listQuery.filter.endtime = this.validTime[1]
            }else{
                this.listQuery.filter.starttime = ''
                this.listQuery.filter.endtime = ''
            }
            let res = await exportArea(this.listQuery)
            if(res.data.code === '200'){
                if(res.data.result === null ||res.data.result === [] || res.data.result.length === 0){
                    this.$message({
                        type:'warning',
                        message:'无数据可导出'
                    })
                }else{
                    let allData = res.data.result
                    import('@/vendor/Export2Excel').then((excel) => {
                        const tHeader = [
                            '地区',
                            '进货数量(箱)',
                            '出货数量(箱)',
                            '销售数量(箱)',
                            '售销额(万元)',
                        ]
                        const filterVal = [
                            'name',
                            'innum',
                            'outnum',
                            'salenum',
                            'sales',
                        ]
                        const data = this.formatJson(filterVal, allData)
                        excel.export_json_to_excel({
                            header: tHeader,
                            data,
                            filename: '地州市进销'
                        })
                    })
                }

            }else{
                this.$message({
                    message:res.data.message,
                    type:'warning'
                })
            }
        },

        formatJson(filterVal, jsonData) {
            return jsonData.map(v => filterVal.map(j => v[j]))
        },

        openDetailDialog(city,validtime,safetysupervision){
             if (validtime == null){
               this.$message({
                 type:'warning',
                 message:'请输入具体时间范围'
               })
             }
             let starttime = validtime[0]
             let endtime = validtime[1]
             let params = {city,starttime,endtime,safetysupervision}
                this.$refs.detail.openDialog(params)
        },

        searchCityInOutSearch(){
            this.listQuery.pageIndex = 1
            const date1 = new Date(this.validTime[0]);
            const date2 = new Date(this.validTime[1]);
            const differenceInMs = Math.abs(date2 - date1);
            const differenceInDays = differenceInMs / (1000 * 60 * 60 * 24)
            if(differenceInDays > 32){
                this.$message({
                    type: 'warning',
                    message: '时间跨度超过一个月的，请联系管理员查询数据'
                })
                return
            }
            this.getCityInOutList()
        },

        handleSizeChange(val) {
            this.listQuery.pageSize = val
            this.getCityInOutList()
        },
        handleCurrentChange(val) {
            this.listQuery.pageIndex = val
            this.getCityInOutList()
        },
      initValidTime(){
        // const start = new Date();
        // const end = new Date();
        // start.setTime(end.getTime() - 3600 * 1000 * 24 * 6);
        // this.validTime[0] = [start.getFullYear(), start.getMonth() + 1, start.getDate()].join("-") + " 00:00:00" ;
        // this.validTime[1] = [end.getFullYear(), end.getMonth() + 1, end.getDate()].join("-") +" 23:59:59";
          const end = new Date();
          this.validTime[0] = end.toISOString().slice(0, 10) + " 00:00:00";
          this.validTime[1] = end.toISOString().slice(0, 10) + " 23:59:59";
      }
    },
}
</script>

<style scoped>
.basic_search{
    display:inline-block;
}

.click-color{
    color: #034ea2;
    cursor: pointer;
}

</style>
